eric7/UI/ClearPrivateDataDialog.py

branch
unittest
changeset 9066
a219ade50f7c
parent 8881
54e42bc2437a
diff -r 39405e6eba20 -r a219ade50f7c eric7/UI/ClearPrivateDataDialog.py
--- a/eric7/UI/ClearPrivateDataDialog.py	Mon May 16 17:22:43 2022 +0200
+++ b/eric7/UI/ClearPrivateDataDialog.py	Mon May 16 19:46:51 2022 +0200
@@ -35,7 +35,7 @@
         
         @return flags indicating which data to clear
             (recent files, recent projects, recent multi projects,
              debug histories, shell histories, unittest histories,
              VCS histories, private data of plugins)
         @rtype tuple of bool
         """
@@ -45,7 +45,7 @@
             self.multiProjectsCheckBox.isChecked(),
             self.debugCheckBox.isChecked(),
             self.shellCheckBox.isChecked(),
-            self.unittestCheckBox.isChecked(),
+            self.testCheckBox.isChecked(),
             self.vcsCheckBox.isChecked(),
             self.pluginsCheckBox.isChecked(),
         )
@@ -35,7 +35,7 @@
         @return flags indicating which data to clear
             (recent files, recent projects, recent multi projects,
-             debug histories, shell histories, unittest histories,
+             debug histories, shell histories, test histories,
              VCS histories, private data of plugins)
         @rtype tuple of bool

eric ide

mercurial